* Alphonse<xalphonse@gmail.com>
Thanks
* Thanks to everyone who works on all the awesome Python data science libraries like numpy, scipy, scikit-image,pillow, etc, etc that makes this kind of stuff so easy and fun in Python.
